@@ -117,6 +117,15 @@ class META():
         except Exception as e:
             return "An error occured report on @metavoidsupport\n\n{}".format(e)
 
+   def chatbot(self, message):
+        try:
+            url = f"{self.url}/api/chatbot?message={message}"           
+            response = get(url, timeout=5)
+            return response.json()
+        except Exception as e:
+            return "An error occured report on @metavoidsupport\n\n{}".format(e)
+
+
     def torrent_1337x(self, text, page):
         try:
             url = f"{self.url}/torrent/1337x?search={text}&page={page}"           
